@@ -17,8 +17,6 @@
 
 """Facts Carousel"""
 
-from nark.items.activity import Activity
-
 from ..crud.fact_dressed import FactDressed
 
 __all__ = (
@@ -32,19 +30,11 @@ class FactsManager_Gap(object):
     def fact_from_interval_gap(self, since_time, until_time):
         self.controller.affirm((not until_time) or (since_time < until_time))
         self.last_fact_pk -= 1
-        activity = Activity(name='')  # (lb): Meh. Seems like Fact should do.
-        gap_fact = FactDressed(
+        gap_fact = FactDressed.new_gap_fact(
             pk=self.last_fact_pk,
-            activity=activity,
             start=since_time,
             end=until_time,
         )
-        # Add 'interval-gap' dirty reason.
-        gap_fact.is_gap = True
-        # Mark deleted until edited, so gap is not saved unless edited.
-        gap_fact.deleted = True
-        # No exceptions! All Fact copies must eventually lead to the original.
-        gap_fact.orig_fact = gap_fact.copy()
         # Add to undo stack. Sorta tricky. Sorta a hack.
         self.on_insert_fact(gap_fact)
         return gap_fact
