@@ -26,7 +26,7 @@ from dob_bright.termio import dob_in_user_warning
 
 from dob_prompt.prompters.interface_bonds import KeyBond
 
-from ..config import json_load_sublisted, pause_on_error_message_maybe
+from ..config import json_load_sublisted
 from ..config.custom_paste import DobViewerConfigCustomPaste
 
 __all__ = (
@@ -131,7 +131,6 @@ class KeyBonder(object):
         if not self.errors:
             return
         dob_in_user_warning('\n'.join(self.errors))
-        pause_on_error_message_maybe()
         self.errors = []
 
     # ***
