@@ -54,6 +54,7 @@ class ZoneDetails(
         self.active_widgets = None
         # Convenience attrs.
         self.affirm = self.carousel.controller.affirm
+        self.debug = self.carousel.controller.client_logger.debug
 
     class HeaderKeyVal(object):
         """"""
@@ -145,12 +146,9 @@ class ZoneDetails(
 
         def add_blank_line():
             self.blank_line = self.make_section_component('', style='class:blank-line')
-            # Note: Somewhere else we set widget.formatted_text_control.style,
-            # but here it's widget.window.style we want.
-            # Note: Also that blank_line.window.style has one PPT default
-            # style and also a style from our code, i.e.,
-            #   blank_line.window.style: 'class:label class:title-normal'
-            self.blank_line.window.style = 'class:blank-line '
+            # Note that PTK add a default style, class:label, before our style, e.g.,,
+            #    self.blank_line.window.style == 'class:label class:blank-line'
+            # Which we'll keep, because it makes setting an application background easy.
             self.children.append(self.blank_line)
 
         # ***
@@ -253,9 +251,12 @@ class ZoneDetails(
         padded = '{:.<19}'.format(name)
         kv_sep = ' : '
 
-        tline_style = 'class:title-normal-line'
-        title_style = 'class:title-normal-line class:title-normal'
+        tline_style, title_style = self.header_line_styles(part_type, set_focus=False)
 
+        # Note that Label() inserts its own style, 'class:label', before
+        # the styles we pass it. We'll leave it, because it lets user put
+        # `label = 'fg#<>'` in their styles.conf to (almost) achieve a
+        # uniform application background (save for the content area).
         labels = [
             self.make_section_component(
                 prefix, style=tline_style, dont_extend_width=True,
@@ -323,7 +324,7 @@ class ZoneDetails(
             orig_val, edit_val, style_class=style_class,
         )
         self.label_duration.val_label.text = diff_tuples
-        self.add_stylable_classes(self.label_duration)
+        self.process_style_rules(self.label_duration)
 
     def refresh_activity(self):
         self.refresh_val_widgets(self.widgets_activity)
@@ -336,14 +337,14 @@ class ZoneDetails(
 
     def refresh_blank_line(self):
         # Lets the user override the blank line style for matching rules.
-        custom_classes = self.carousel.add_stylable_classes(
+        custom_classes = self.carousel.process_style_rules(
             ppt_widget=None, friendly_name='blank-line',
         )
-        # (lb): I'm wondering if we should just clobber style, not append
-        # (and do so other places we fiddle with style).
-        # Probably not necessary:
-        #   self.blank_line.window.style = 'class:blank-line ' + custom_classes
-        self.blank_line.window.style = custom_classes or 'class:blank-line '
+        # - (lb): Rules replace, not append, widget's style. #rule_replace
+        #   I.e., not;
+        #       ...style = 'class:label class:blank-line ' + custom_classes
+        #   This was an arbitrary choice. If it's better the other way, we can switch.
+        self.blank_line.window.style = custom_classes or 'class:label class:blank-line '
 
     def refresh_val_widgets(self, keyval_widgets):
         self.affirm(keyval_widgets.fact_attr)
@@ -361,19 +362,20 @@ class ZoneDetails(
         #     'class:label class:value-normal-line'
         # and now we'll set value-{normal|activity|category|etc}[-line], if rules apply.
         # (lb): Note also widgets_start and widgets_end come through here.
-        self.add_stylable_classes(keyval_widgets)
+        self.process_style_rules(keyval_widgets)
 
     def assemble_style_class_for_part(self, keyval_widgets):
         style_class = 'class:value-normal '
         style_class += 'class:value-{} '.format(keyval_widgets.what_part)
         return style_class
 
-    def add_stylable_classes(self, keyval_parts, set_focus=None):
-        self.add_stylable_classes_header_titles(keyval_parts, set_focus)
-        self.add_stylable_classes_header_values_normal(keyval_parts)
-        self.add_stylable_classes_header_values_focus(keyval_parts, set_focus)
+    def process_style_rules(self, keyval_parts, set_focus=None):
+        # (lb): Reminder that rules replace, not append, widget's style. #rule_replace
+        self.process_style_rules_header_titles(keyval_parts, set_focus)
+        self.process_style_rules_header_values_normal(keyval_parts)
+        self.process_style_rules_header_values_focus(keyval_parts, set_focus)
 
-    def add_stylable_classes_header_titles(self, keyval_parts, set_focus=None):
+    def process_style_rules_header_titles(self, keyval_parts, set_focus=None):
         # keyval_parts.key_parts is a list of Labels (from make_header_label_parts).
         # - The first item is the left column padding. E.g.: '  '.
         # - The second item is the meta label and the ...-padding.
@@ -400,23 +402,23 @@ class ZoneDetails(
         for friendly_name in friendlies:
             # Register the -line style, which means assigns same style to all parts.
             for label in keyval_parts.key_parts:
-                self.carousel.add_stylable_classes(label, friendly_name + '-line')
+                self.carousel.process_style_rules(label, friendly_name + '-line')
             # Register title-[normal|duration|start|end|activity|category|tags][-focus]
             # on just the title label part of the header.
-            self.carousel.add_stylable_classes(dot_padded_title, friendly_name)
+            self.carousel.process_style_rules(dot_padded_title, friendly_name)
 
-    def add_stylable_classes_header_values_normal(self, keyval_parts):
+    def process_style_rules_header_values_normal(self, keyval_parts):
         # For matching rules, apply rule styles for: value-normal, value-normal-line,
         # and value-[duration|start|end|activity|category|tags][-line]
         value_part = 'value-{}'.format(keyval_parts.what_part)
         for friendly_name in ('value-normal', value_part):
             for suffix in ('-line', ''):
-                self.carousel.add_stylable_classes(
+                self.carousel.process_style_rules(
                     keyval_parts.val_label,
                     friendly_name + suffix,
                 )
 
-    def add_stylable_classes_header_values_focus(self, keyval_parts, set_focus=False):
+    def process_style_rules_header_values_focus(self, keyval_parts, set_focus=False):
         if not set_focus:
             return
 
@@ -425,13 +427,35 @@ class ZoneDetails(
         value_part = 'value-{}-focus'.format(keyval_parts.what_part)
         for friendly_name in ('value-focus', value_part):
             for suffix in ('-line', ''):
-                self.carousel.add_stylable_classes(
+                self.carousel.process_style_rules(
                     keyval_parts.text_area,
                     friendly_name + suffix,
                 )
 
     # ***
 
+    def header_line_styles(self, part_type, set_focus=False):
+        focus_state = set_focus and 'focus' or 'normal'
+        # Set classes on each part, title-normal-line, or title-focus-line.
+        # Set also on inner text, title-normal or title-focus.
+        title_base_class = 'class:title-{}'.format(focus_state)
+        title_line_class = '{}-line'.format(title_base_class)
+        # Set classes more specific to the part type, e.g.,
+        # title-[duration|start|end|activity|category|tags][-focus][-line].
+        tpart_base_class = 'class:title-{}'.format(part_type)
+        if set_focus:
+            tpart_base_class += '-{}'.format(focus_state)  # += '-focus'
+        tpart_line_class = '{}-line'.format(tpart_base_class)
+
+        line_classes = '{} {} '.format(title_line_class, tpart_line_class)
+        text_classes = '{} {} {} {} '.format(
+            title_line_class, title_base_class, tpart_line_class, tpart_base_class,
+        )
+
+        return line_classes, text_classes
+
+    # ***
+
     def replace_val_container(
         self,
         val_container,
@@ -442,34 +466,27 @@ class ZoneDetails(
 
         focus_state = set_focus and 'focus' or 'normal'
 
-        # ***
-
-        # Set classes on each part, title-normal-line, or title-focus-line.
-        # Set also on inner text, title-normal or title-focus.
-        # This clobbers default style that PPT uses on Label, 'class:label '.
-        title_base_class = 'class:title-{}'.format(focus_state)
-        title_line_class = '{}-line'.format(title_base_class)
-        # Set classes more specific to the part type, e.g.,
-        # title-[duration|start|end|activity|category|tags][-focus][-line].
-        tpart_base_class = 'class:title-{}'.format(keyval_widgets.what_part)
-        if set_focus:
-            tpart_base_class += '-{}'.format(focus_state)  # += '-focus'
-        tpart_line_class = '{}-line'.format(tpart_base_class)
-
-        line_classes = '{} {} '.format(title_line_class, tpart_line_class)
-        text_classes = '{} {} {} {} '.format(
-            title_line_class, title_base_class, tpart_line_class, tpart_base_class,
+        line_classes, text_classes = self.header_line_styles(
+            keyval_widgets.what_part, set_focus=set_focus,
         )
+        # (lb): PTK assigns the same 'class:label' to all widgets. If we maintain it,
+        # then the user can set, e.g., "label = 'bg:#00AA66'" in their styles.conf to
+        # set a universal background color (well, except for content area and border).
+        ptk_label_class = 'class:label '
+        line_classes = ptk_label_class + line_classes
+        text_classes = ptk_label_class + text_classes
 
         keyval_vsplit.get_children()[0].style = line_classes
+
         title_widget = keyval_vsplit.get_children()[1]
         title_widget.style = text_classes
+
         keyval_vsplit.get_children()[2].style = line_classes
 
         # ***
 
         # On Label, to_container gets val_container.formatted_text_control.
-        # On TextArea, to_container get val_container.window.
+        # On TextArea, to_container gets val_container.window.
         value_widget = to_container(val_container)
         # Set class on value component, value-normal-line, or value-focus-line.
         value_line_class = 'class:value-{}-line '.format(focus_state)
@@ -480,12 +497,12 @@ class ZoneDetails(
             value_part_class += '-focus'
         value_part_class += '-line'
         # This clobbers default style that PPT use on TextArea, 'class:text-area '.
-        value_widget.style = value_line_class + value_part_class
+        value_widget.style = ptk_label_class + value_line_class + value_part_class
         keyval_vsplit.get_children()[3] = value_widget
 
         # ***
 
-        self.add_stylable_classes(keyval_widgets, set_focus=set_focus)
+        self.process_style_rules(keyval_widgets, set_focus=set_focus)
 
     def replace_val_container_label(self, keyval_widgets):
         self.replace_val_container(
@@ -545,12 +562,10 @@ class ZoneDetails(
             return keyval_widgets.text_area.text != keyval_widgets.orig_val
 
         def debug_log_text():
-            self.carousel.controller.client_logger.debug(
-                'text_area.text: {} / orig_val: {}'.format(
-                    keyval_widgets.text_area.text,
-                    keyval_widgets.orig_val,
-                )
-            )
+            self.debug('text_area.text: {} / orig_val: {}'.format(
+                keyval_widgets.text_area.text,
+                keyval_widgets.orig_val,
+            ))
 
         def refresh_keyval():
             # Refresh labels now, so that old value isn't shown briefly and then
@@ -572,7 +587,7 @@ class ZoneDetails(
     # ***
 
     def edit_time_any_key(self, event=None):
-        self.carousel.controller.client_logger.debug('event: {}'.format(event))
+        self.debug('event: {}'.format(event))
         # Ignore all alpha characters except those for [t|T]imezone delimiter.
         if event.data.isalpha() and event.data not in ('t', 'T'):
             return
@@ -613,9 +628,7 @@ class ZoneDetails(
             return leave_okayed[0]
 
         def apply_edited_time(edit_fact, edit_text):
-            self.carousel.controller.client_logger.debug(
-                'edit_time_enter: edit_text: {}'.format(edit_text)
-            )
+            self.debug('edit_time_enter: edit_text: {}'.format(edit_text))
             if not edit_text:
                 apply_edit_time_removed(edit_fact)
             else:
@@ -742,9 +755,7 @@ class ZoneDetails(
                 other_edits=other_edits,
                 suppress_barf=True,
             )
-            self.carousel.controller.client_logger.debug(
-                'no. conflicts found: {}'.format(len(conflicts))
-            )
+            self.debug('no. conflicts found: {}'.format(len(conflicts)))
             return conflicts
 
         # ***
@@ -847,9 +858,7 @@ class ZoneDetails(
                 pattern += r'(..)'
                 replace += r':\5'
             reformatted = re.sub(pattern, replace, numberless)
-            self.carousel.controller.client_logger.debug(
-                'reformatted: {}'.format(reformatted)
-            )
+            self.debug('reformatted: {}'.format(reformatted))
             return reformatted
 
         return _parse_dated()
