@@ -22,8 +22,7 @@ from gettext import gettext as _
 import os
 from inflector import English, Inflector
 
-# MAYBE/2019-12-05: (lb): Decouple dob-viewer from click, used only for term. size.
-import click_hotoffthehamster as click  # merely for get_terminal_size.
+import click_hotoffthehamster as click
 
 # Profiling: load prompt_toolkit. ~ 0.040 secs.
 from prompt_toolkit.application import Application
@@ -80,6 +79,7 @@ class ZoneManager(object):
         self.root = self.build_root_container()
         self.layout = self.build_application_layout()
         self.setup_styling()
+        self.center_thyself()
         self.application = self.build_application_object(**kwargs)
         self.rebuild_viewable()
 
@@ -158,6 +158,17 @@ class ZoneManager(object):
             dob_in_user_warning(msg)
             self.style = Style([])
 
+    def center_thyself(self):
+        if not self.carousel.controller.config['editor.centered']:
+            return
+        click.clear()
+        # (lb): Revisit this? A little hacky.
+        # Newlines seem to nudge Carousel centered.
+        # Not sure why 3 is magic number, or if always.
+        click.echo()
+        click.echo()
+        click.echo()
+
     def _detect_color_depth(self):
         # MAYBE/2020-01-06: Make color_depth configurable. Or detect better.
         # (lb): This is a little frustrating. Colors are true in mate-terminal, but
@@ -213,6 +224,10 @@ class ZoneManager(object):
             # FIXME: Make this feature optionable. Seems like some
             #   people may appreciate this wiring.
             mouse_support=True,
+            # (lb): I tried changing style at runtime, e.g., editing a class
+            # name's 'fg:#xxxxxx' value in the Application style_rules, but
+            # it did not have an impact. So stick to adding and removing
+            # class names from each widget's style component, which works.
             style=self.style,
             # The scrollable content area disables input with
             #   read_only=True
